geotree<-function(tr,loc,path,vscl=1.5,elev=NA) {
	#tr: an hclust tree (NOT an ape phylo)
	#loc: matrix where columns are (long, lat) coords of each tip in tree
	#path: output .kml file
	#vscl: vertical tree height, by default 1.5x the maximum distance between tips
	#elev: the fraction of the tree's height that each tip is suspended above the earth's surface, either a constant, or a vector for each point (e.g. for ancient samples)
	require(geosphere)
	file(path,open="wt")->zz
	cat("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<kml xmlns=\"http://www.opengis.net/kml/2.2\">\n<Document>",file=zz)
	cat("\n  <Style id=\"RedPhylo\">\n    <LineStyle>\n      <width>5</width>\n      <color>#AA0000FF</color>\n    </LineStyle>\n  </Style>",file=zz)
	cat("\n  <Style id=\"BluePin\">\n    <LineStyle>\n      <width>3</width>\n      <color>#AAFFAAAA</color>\n    </LineStyle>\n  </Style>",file=zz)
	
	#tree sits 1/10th range-of-locs above earth, and extends upwards 1.5x range
	maxd=0
	for(i in 2:nrow(loc)-1) for(j in 2:nrow(loc))
		if(distHaversine(loc[i,],loc[j,])>maxd) maxd=distHaversine(loc[i,],loc[j,])
	h=maxd*vscl 
	if(is.na(elev[1])) elevate=rep(maxd/10,nrow(loc)) else 
		if(length(elev)==1) elevate=rep(maxd*elev,nrow(loc)) else elevate=maxd*elev
	
	#place blue pins at locs
	for(i in 1:nrow(loc)) { 
		cat("\n  <Placemark>\n    <styleUrl>#BluePin</styleUrl>\n    <LineString>\n      <altitudeMode>absolute</altitudeMode>\n      <coordinates>",file=zz)
		cat(c(loc[i,],0),sep=",",file=zz); cat(" ",file=zz); cat(c(loc[i,],elevate[i]),sep=",",file=zz)
		cat("</coordinates>\n    </LineString>\n  </Placemark>",file=zz)
	}
	
	#calculate 3d coords of tree
	intnode=c();
	treecoord=matrix(NA,nr=0,nc=3)
	for(i in 1:nrow(otr$merge)) {
		if(otr$merge[i,1]<0) pt1=c(loc[-otr$merge[i,1],],elevate[-otr$merge[i,1]]) else pt1=intnode[otr$merge[i,1],]
		if(otr$merge[i,2]<0) pt2=c(loc[-otr$merge[i,2],],elevate[-otr$merge[i,1]]) else pt2=intnode[otr$merge[i,2],]
		midp=c(midPoint(pt1[1:2],pt2[1:2]),otr$height[i]*h+min(elevate))
		if(midp[1]>180) midp[1]=midp[1]-360 #keep W long coords negative
		if(length(intnode)==0) intnode=matrix(midp,nr=1) else intnode=rbind(intnode,midp)
		treecoord=rbind(treecoord,pt1,midp,pt2)
	}
	
	#output to file
	for(i in 1:(nrow(treecoord)/3)) {
		cat("\n  <Placemark>\n    <styleUrl>#RedPhylo</styleUrl>\n    <LineString>\n      <altitudeMode>absolute</altitudeMode>\n      <coordinates>",file=zz)
		for(j in 2:0) {
			cat("\n         ",file=zz)
			cat(treecoord[i*3-j,],sep=",",file=zz)
		}
		cat("\n      </coordinates>\n   </LineString>\n  </Placemark>",file=zz)
	}
	cat("\n</Document>\n</kml>",file=zz)
	close(zz)
}
